@@ -5,6 +5,7 @@ from selenium import webdriver
 from selenium.webdriver.chrome.options import Options
 from contextlib import contextmanager
 from .exceptions import MissingBitWardenToken, BrowserException
+from pyvirtualdisplay import Display
 
 class BaseScrap:
 
@@ -42,11 +43,18 @@ def BrowserGCM(headless=True):
         chrome_options = Options()
         if _headless:
             chrome_options.add_argument("--headless")
+            chrome_options.add_argument("--no-sandbox")
+
+        # import pudb;pu.db
+        # display = Display(visible=0, size=(800, 600))
+        # display.start()
+
         return webdriver.Chrome(options=chrome_options)
     try:
         _browser = init_browser(headless)
         yield _browser
     except Exception as exc:
+        print(exc)
         raise BrowserException(exc)
     finally:
         _browser.quit()
